@@ -42,7 +42,6 @@ from scriptworker.task import (
     get_pull_request_number,
     get_push_date_time,
     get_repo,
-    get_repo_scope,
     get_revision,
     get_task_id,
     get_triggered_by,
@@ -53,6 +52,8 @@ from scriptworker.task import (
 )
 from scriptworker.utils import (
     add_enumerable_item_to_dict,
+    add_projectid,
+    add_taskqueueid,
     format_json,
     get_hash,
     get_loggable_url,
@@ -162,6 +163,28 @@ class ChainOfTrust(object):
         """
         return self.task_type in DECISION_TASK_TYPES
 
+    def is_scope_in_restricted_scopes(self, scope, restricted_scopes):
+        """Determine if a scope matches in a list of restricted_scopes.
+           if one of the restricted scopes ends with '*', find a partial match.
+
+        Returns:
+            String: string of matching restricted_scope, if no match ""
+        """
+        match = []
+        for restricted in restricted_scopes:
+            if restricted.endswith("*"):
+                if scope.startswith(restricted.rstrip("*")):
+                    match.append(restricted)
+            elif scope == restricted:
+                match.append(restricted)
+
+        if len(match) > 1:
+            raise CoTError("Scope {} matches >1 restricted_scope: {}\n".format(scope, match))
+        elif len(match) == 1:
+            return match[0]
+        else:
+            return ""
+
     def has_restricted_scopes(self):
         """Determine if this task is requesting any restricted scopes.
 
@@ -169,7 +192,7 @@ class ChainOfTrust(object):
             bool: whether this task requested restricted scopes.
 
         """
-        return any((scope in self.context.config["cot_restricted_scopes"]) for scope in self.task["scopes"])
+        return any((self.is_scope_in_restricted_scopes(scope, self.context.config["cot_restricted_scopes"])) for scope in self.task["scopes"])
 
     def get_all_links_in_chain(self):
         """Return all links in the chain of trust, including the target task.
@@ -417,7 +440,6 @@ def get_valid_task_types():
             "decision": verify_parent_task,
             "docker-image": verify_docker_image_task,
             "pushapk": verify_scriptworker_task,
-            "pushsnap": verify_scriptworker_task,
             "shipit": verify_scriptworker_task,
             "signing": verify_scriptworker_task,
             "partials": verify_partials_task,
@@ -1351,14 +1373,13 @@ async def get_in_tree_template(link):
 
 def _get_action_from_actions_json(all_actions, callback_name):
     for defn in all_actions:
-        if defn.get("kind") == "hook":
-            if defn.get("hookPayload", {}).get("decision", {}).get("action", {}).get("cb_name") == callback_name:
-                return defn
-        elif defn.get("kind") == "task":
-            if defn.get("task", {}).get("$let", {}).get("action", {}).get("cb_name") == callback_name:
-                return defn
-        else:
-            raise CoTError("Unknown action kind `{kind}` for action `{name}`.".format(kind=defn.get("kind", "<MISSING>"), name=defn.get("name", "<MISSING>")))
+        if defn.get("hookPayload", {}).get("decision", {}).get("action", {}).get("cb_name") == callback_name:
+            if defn.get("kind") != "hook":
+                raise CoTError(
+                    "Unknown action kind `{kind}` for action `{name}`.".format(kind=defn.get("kind", "<MISSING>"), name=defn.get("name", "<MISSING>"))
+                )
+
+            return defn
     raise CoTError("No action with {} callback found.".format(callback_name))
 
 
@@ -1437,37 +1458,29 @@ async def get_action_context_and_template(chain, parent_link, decision_link):
     action_name = get_action_callback_name(parent_link.task)
     action_defn = _get_action_from_actions_json(all_actions, action_name)
     jsone_context = await populate_jsone_context(chain, parent_link, decision_link, "action")
-    if "task" in action_defn and chain.context.config["min_cot_version"] <= 2:
-        tmpl = {"tasks": [action_defn["task"]]}
-    elif action_defn.get("kind") == "hook":
-        # action-hook.
-        in_tree_tmpl = await get_in_tree_template(decision_link)
-        action_perm = _get_action_perm(action_defn)
-        tmpl = _wrap_action_hook_with_let(in_tree_tmpl, action_perm)
 
-        # define the JSON-e context with which the hook's task template was
-        # rendered, defined at
-        # https://firefox-ci-tc.services.mozilla.com/docs/reference/core/hooks/firing-hooks#triggerhook
-        # This is created by working backward from the json-e context the
-        # .taskcluster.yml expects
-        jsone_context = {
-            "payload": _render_action_hook_payload(action_defn, jsone_context, parent_link),
-            "taskId": parent_link.task_id,
-            "now": jsone_context["now"],
-            "as_slugid": jsone_context["as_slugid"],
-            "clientId": jsone_context.get("clientId"),
-        }
-    elif action_defn.get("kind") == "task":
-        # XXX Get rid of this block when all actions are hooks
-        tmpl = await get_in_tree_template(decision_link)
-        for k in ("action", "push", "repository"):
-            jsone_context[k] = deepcopy(action_defn["hookPayload"]["decision"].get(k, {}))
-        jsone_context["action"]["repo_scope"] = get_repo_scope(parent_link.task, parent_link.name)
-    else:
+    if action_defn.get("kind") != "hook":
         raise CoTError(
             "Unknown action kind `{kind}` for action `{name}`.".format(kind=action_defn.get("kind", "<MISSING>"), name=action_defn.get("name", "<MISSING>"))
         )
 
+    # action-hook.
+    in_tree_tmpl = await get_in_tree_template(decision_link)
+    action_perm = _get_action_perm(action_defn)
+    tmpl = _wrap_action_hook_with_let(in_tree_tmpl, action_perm)
+
+    # define the JSON-e context with which the hook's task template was
+    # rendered, defined at
+    # https://firefox-ci-tc.services.mozilla.com/docs/reference/core/hooks/firing-hooks#triggerhook
+    # This is created by working backward from the json-e context the
+    # .taskcluster.yml expects
+    jsone_context = {
+        "payload": _render_action_hook_payload(action_defn, jsone_context, parent_link),
+        "taskId": parent_link.task_id,
+        "now": jsone_context["now"],
+        "as_slugid": jsone_context["as_slugid"],
+        "clientId": jsone_context.get("clientId"),
+    }
     return jsone_context, tmpl
 
 
@@ -1597,6 +1610,15 @@ def compare_jsone_task_definition(parent_link, rebuilt_definitions):
         compare_definition = remove_empty_keys(compare_definition)
         runtime_definition = remove_empty_keys(parent_link.task)
 
+        # add projectId properties if they do not already appear
+        compare_definition = add_projectid(compare_definition)
+        runtime_definition = add_projectid(runtime_definition)
+
+        # add taskQueueId properties if they do not already appear, and
+        # remove provisionerId / workerType
+        compare_definition = add_taskqueueid(compare_definition)
+        runtime_definition = add_taskqueueid(runtime_definition)
+
         diff = list(dictdiffer.diff(compare_definition, runtime_definition))
         if diff:
             diffs.append(pprint.pformat(diff))
@@ -1896,9 +1918,10 @@ async def trace_back_to_tree(chain):
     # check for restricted scopes.
     my_repo = repos[chain]
     for scope in chain.task["scopes"]:
-        if scope in rules["scopes"]:
+        matched_scope = chain.is_scope_in_restricted_scopes(scope, rules["scopes"])
+        if matched_scope:
             log.info("Found privileged scope {}".format(scope))
-            level = rules["scopes"][scope]
+            level = rules["scopes"][matched_scope]
             if my_repo not in rules["trees"][level]:
                 errors.append("{} {}: repo {} not allowlisted for scope {}!".format(chain.name, chain.task_id, my_repo, scope))
     # verify all tasks w/ same decision_task_id have the same source repo.
@@ -2046,13 +2069,13 @@ SCRIPTWORKER_GITHUB_OAUTH_TOKEN to an OAUTH token with read permissions to the r
     log.setLevel(level)
     logging.basicConfig(level=level)
     event_loop = event_loop or asyncio.get_event_loop()
+    if not opts.cleanup:
+        log.info("Artifacts will be in {}".format(tmp))
     try:
         event_loop.run_until_complete(_async_verify_cot_cmdln(opts, tmp))
     finally:
         if opts.cleanup:
             rm(tmp)
-        else:
-            log.info("Artifacts are in {}".format(tmp))
 
 
 # create_test_workdir {{{1
